@@ -19,13 +19,17 @@ from xp.services.telegram.telegram_version_service import (
 @click.argument("serial_number", type=SERIAL)
 @handle_service_errors(VersionParsingError)
 def generate_version_request(serial_number: str) -> None:
-    """
-    Generate a telegram to request version information from a device.
+    r"""Generate a telegram to request version information from a device.
+
+    Args:
+        serial_number: 10-digit module serial number.
 
     Examples:
-
-    \b
+        \b
         xp telegram version 0012345011
+
+    Raises:
+        SystemExit: If request cannot be generated.
     """
     service = VersionService()
     formatter = OutputFormatter(True)
