@@ -11,11 +11,23 @@ from xp.models.telegram.system_telegram import SystemTelegram
 
 @dataclass
 class LogEntry:
-    """
-    Represents a single entry in a console bus log file.
+    """Represents a single entry in a console bus log file.
 
     Format: HH:MM:SS,mmm [TX/RX] <telegram>
     Examples: 22:44:20,352 [TX] <S0012345008F27D00AAFN>
+
+    Attributes:
+        timestamp: Timestamp of the log entry.
+        direction: Direction of telegram ("TX" or "RX").
+        raw_telegram: Raw telegram string.
+        parsed_telegram: Parsed telegram object if successfully parsed.
+        parse_error: Error message if parsing failed.
+        line_number: Line number in the log file.
+        is_transmitted: True if this is a transmitted telegram.
+        is_received: True if this is a received telegram.
+        telegram_type: Telegram type (event, system, reply, unknown).
+        is_valid_parse: True if the telegram was successfully parsed.
+        checksum_validated: Checksum validation status if available.
     """
 
     timestamp: datetime
@@ -29,17 +41,29 @@ class LogEntry:
 
     @property
     def is_transmitted(self) -> bool:
-        """True if this is a transmitted telegram"""
+        """True if this is a transmitted telegram.
+
+        Returns:
+            True if direction is TX, False otherwise.
+        """
         return self.direction == "TX"
 
     @property
     def is_received(self) -> bool:
-        """True if this is a received telegram"""
+        """True if this is a received telegram.
+
+        Returns:
+            True if direction is RX, False otherwise.
+        """
         return self.direction == "RX"
 
     @property
     def telegram_type(self) -> str:
-        """Get the telegram type (event, system, reply, unknown)"""
+        """Get the telegram type (event, system, reply, unknown).
+
+        Returns:
+            Telegram type string.
+        """
         if self.parsed_telegram is None:
             return "unknown"
 
@@ -47,18 +71,30 @@ class LogEntry:
 
     @property
     def is_valid_parse(self) -> bool:
-        """True if the telegram was successfully parsed"""
+        """True if the telegram was successfully parsed.
+
+        Returns:
+            True if parsed without errors, False otherwise.
+        """
         return self.parsed_telegram is not None and self.parse_error is None
 
     @property
     def checksum_validated(self) -> Optional[bool]:
-        """Get checksum validation status if available"""
+        """Get checksum validation status if available.
+
+        Returns:
+            Checksum validation status or None if not available.
+        """
         if self.parsed_telegram and hasattr(self.parsed_telegram, "checksum_validated"):
             return self.parsed_telegram.checksum_validated
         return None
 
     def to_dict(self) -> dict[str, Any]:
-        """Convert to dictionary for JSON serialization"""
+        """Convert to dictionary for JSON serialization.
+
+        Returns:
+            Dictionary representation of the log entry.
+        """
         result: dict[str, Any] = {
             "line_number": self.line_number,
             "timestamp": self.timestamp.strftime("%H:%M:%S.%f")[
@@ -79,7 +115,11 @@ class LogEntry:
         return result
 
     def __str__(self) -> str:
-        """Human-readable string representation"""
+        """Human-readable string representation.
+
+        Returns:
+            Formatted string representation of the log entry.
+        """
         timestamp_str = self.timestamp.strftime("%H:%M:%S,%f")[:-3]  # HH:MM:SS,mmm
         status = "✓" if self.is_valid_parse else "✗"
         checksum_status = ""
