@@ -1,6 +1,6 @@
 """Integration tests for ActionTable functionality."""
 
-import json
+from dataclasses import asdict
 from unittest.mock import Mock
 
 import pytest
@@ -13,18 +13,15 @@ from xp.models import ModuleTypeCode
 from xp.models.actiontable.actiontable import ActionTable, ActionTableEntry
 from xp.models.telegram.input_action_type import InputActionType
 from xp.models.telegram.timeparam_type import TimeParam
-from xp.services.conbus.actiontable.actiontable_service import (
-    ActionTableSerializer,
-    ActionTableService,
-)
+from xp.services.actiontable.actiontable_serializer import ActionTableSerializer
 
 
 class TestActionTableIntegration:
-    """Integration tests for ActionTable components"""
+    """Integration tests for ActionTable components."""
 
     @pytest.fixture
     def sample_actiontable(self):
-        """Create sample ActionTable for testing"""
+        """Create sample ActionTable for testing."""
         entries = [
             ActionTableEntry(
                 module_type=ModuleTypeCode.CP20,
@@ -32,7 +29,7 @@ class TestActionTableIntegration:
                 module_input=0,
                 module_output=1,
                 inverted=False,
-                command=InputActionType.TURNOFF,
+                command=InputActionType.OFF,
                 parameter=TimeParam.NONE,
             ),
             ActionTableEntry(
@@ -41,14 +38,14 @@ class TestActionTableIntegration:
                 module_input=1,
                 module_output=2,
                 inverted=True,
-                command=InputActionType.TURNON,
+                command=InputActionType.ON,
                 parameter=TimeParam.NONE,
             ),
         ]
         return ActionTable(entries=entries)
 
     def test_serializer_roundtrip(self, sample_actiontable):
-        """Test ActionTableSerializer encode/decode roundtrip"""
+        """Test ActionTableSerializer encode/decode roundtrip."""
         serializer = ActionTableSerializer()
 
         # Serialize to bytes
@@ -71,7 +68,7 @@ class TestActionTableIntegration:
         assert restored_entry.module_output == original_entry.module_output
 
     def test_serializer_encoded_string_roundtrip(self, sample_actiontable):
-        """Test ActionTableSerializer base64 string roundtrip"""
+        """Test ActionTableSerializer base64 string roundtrip."""
         serializer = ActionTableSerializer()
 
         # Encode to string
@@ -85,45 +82,46 @@ class TestActionTableIntegration:
         assert len(restored_table.entries) == len(sample_actiontable.entries)
 
     def test_serializer_format_output(self, sample_actiontable):
-        """Test ActionTableSerializer output formatting"""
+        """Test ActionTableSerializer output formatting."""
         serializer = ActionTableSerializer()
 
         # Test decoded output format
         decoded = serializer.format_decoded_output(sample_actiontable)
-        expected_lines = ["CP20 0 0 > 1 TURNOFF;", "CP20 0 1 > 2 ~TURNON;"]
-        assert decoded == "\n".join(expected_lines)
+        expected_lines = ["CP20 0 0 > 1 OFF;", "CP20 0 1 > 2 ~ON;"]
+        assert decoded == expected_lines
 
         # Test encoded output format
         encoded = serializer.to_encoded_string(sample_actiontable)
         assert isinstance(encoded, str)
         assert len(encoded) > 0
 
-    def test_service_serializer_integration(self, sample_actiontable):
-        """Test ActionTableService and ActionTableSerializer integration"""
-        # Setup service with mocked dependencies
-        mock_conbus = Mock()
-        mock_telegram = Mock()
-        service = ActionTableService(
-            conbus_service=mock_conbus,
-            telegram_service=mock_telegram,
-        )
-
-        # Test formatting methods work
-        decoded = service.format_decoded_output(sample_actiontable)
-        encoded = service.format_encoded_output(sample_actiontable)
-
-        assert isinstance(decoded, str)
-        assert isinstance(encoded, str)
-        assert "CP20 0 0 > 1 TURNOFF;" in decoded
-        assert len(encoded) > 0
-
     def test_end_to_end_cli_download(self, sample_actiontable):
-        """Test end-to-end CLI download functionality"""
+        """Test end-to-end CLI download functionality."""
         # Setup mock service
         mock_service = Mock()
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
-        mock_service.download_actiontable.return_value = sample_actiontable
+
+        # Mock the start method to call finish_callback immediately
+        def mock_start(
+            serial_number, progress_callback, finish_callback, error_callback
+        ):
+            """Test helper function.
+
+            Args:
+                serial_number: Serial number of the module.
+                progress_callback: Callback for progress updates.
+                finish_callback: Callback when finished.
+                error_callback: Callback for errors.
+            """
+            # Generate dict and short format like the service does
+            actiontable_dict = asdict(sample_actiontable)
+            actiontable_short = ActionTableSerializer.format_decoded_output(
+                sample_actiontable
+            )
+            finish_callback(sample_actiontable, actiontable_dict, actiontable_short)
+
+        mock_service.start.side_effect = mock_start
 
         # Setup mock container
         mock_container = Mock()
@@ -142,17 +140,16 @@ class TestActionTableIntegration:
         # Verify successful execution
         assert result.exit_code == 0
 
-        # Verify output is valid JSON
-        output_data = json.loads(result.output)
-        assert "serial_number" in output_data
-        assert "actiontable" in output_data
-        assert output_data["serial_number"] == "0000012345"
+        # Verify output contains actiontable data
+        # The output contains progress dots and then the JSON, so we check for the serial number
+        assert "0000012345" in result.output
+        assert "actiontable" in result.output
 
-        # Verify service was called correctly
-        mock_service.download_actiontable.assert_called_once_with("0000012345")
+        # Verify service.start was called
+        assert mock_service.start.called
 
     def test_bcd_encoding_decoding(self):
-        """Test BCD encoding/decoding functionality"""
+        """Test BCD encoding/decoding functionality."""
         from xp.utils.serialization import de_bcd, to_bcd
 
         # Test BCD conversion
@@ -164,7 +161,7 @@ class TestActionTableIntegration:
                 assert decoded == value
 
     def test_bit_manipulation(self):
-        """Test bit manipulation functions"""
+        """Test bit manipulation functions."""
         from xp.utils.serialization import lower3, upper5
 
         # Test lower 3 bits extraction
@@ -177,28 +174,29 @@ class TestActionTableIntegration:
         assert upper5_result == 0b11110  # 30
 
     def test_actiontable_empty_entries(self):
-        """Test ActionTable with empty entries"""
+        """Test ActionTable with empty entries."""
         empty_table = ActionTable(entries=[])
         serializer = ActionTableSerializer()
 
-        # Should handle empty table gracefully
+        # Empty table should be padded to 96 entries (480 bytes) during serialization
         data = serializer.to_data(empty_table)
         assert isinstance(data, bytes)
-        assert len(data) == 0
+        assert len(data) == 480  # 96 entries × 5 bytes
+        assert data == b"\x00" * 480  # All padding (NOMOD entries)
 
-        # Restore empty table
+        # Restore table - padding (NOMOD entries) is stripped during deserialization
         restored = serializer.from_data(data)
-        assert len(restored.entries) == 0
+        assert len(restored.entries) == 0  # Padding removed
 
     def test_actiontable_edge_cases(self):
-        """Test ActionTable with edge case values"""
+        """Test ActionTable with edge case values."""
         edge_entry = ActionTableEntry(
             module_type=ModuleTypeCode.CP20,
             link_number=99,  # Max BCD value
             module_input=99,  # Max BCD value
             module_output=7,  # Max 3-bit value
             inverted=False,
-            command=InputActionType.TURNOFF,
+            command=InputActionType.OFF,
             parameter=TimeParam.NONE,
         )
         edge_table = ActionTable(entries=[edge_entry])
