@@ -10,7 +10,6 @@ from xp.models.actiontable.msactiontable_xp24 import InputAction, Xp24MsActionTa
 from xp.models.telegram.input_action_type import InputActionType
 from xp.models.telegram.timeparam_type import TimeParam
 from xp.services.conbus.actiontable.msactiontable_service import (
-    MsActionTableError,
     MsActionTableService,
 )
 from xp.utils.dependencies import ServiceContainer
@@ -20,14 +19,13 @@ class TestXp24ActionTableIntegration:
     """Integration tests for XP24 action table CLI operations."""
 
     def setup_method(self):
-        """Set up test fixtures"""
+        """Set up test fixtures."""
         self.runner = CliRunner()
         self.valid_serial = "0123450001"
         self.invalid_serial = "1234567890"  # Valid format but will cause service error
 
     def test_xp24_download_action_table(self):
-        """Test downloading action table from module"""
-
+        """Test downloading action table from module."""
         # Create mock service
         mock_service = Mock(spec=MsActionTableService)
         mock_service.__enter__ = Mock(return_value=mock_service)
@@ -36,7 +34,7 @@ class TestXp24ActionTableIntegration:
         # Create mock action table
         mock_action_table = Xp24MsActionTable(
             input1_action=InputAction(InputActionType.TOGGLE, TimeParam.NONE),
-            input2_action=InputAction(InputActionType.TURNON, TimeParam.T5SEC),
+            input2_action=InputAction(InputActionType.ON, TimeParam.T5SEC),
             input3_action=InputAction(InputActionType.LEVELSET, TimeParam.T2MIN),
             input4_action=InputAction(InputActionType.SCENESET, TimeParam.T2MIN),
             mutex12=False,
@@ -46,7 +44,26 @@ class TestXp24ActionTableIntegration:
             curtain34=True,
         )
 
-        mock_service.download_action_table.return_value = mock_action_table
+        # Mock the start method to call finish_callback immediately
+        def mock_start(
+            serial_number,
+            xpmoduletype,
+            progress_callback,
+            finish_callback,
+            error_callback,
+        ):
+            """Test helper function.
+
+            Args:
+                serial_number: Serial number of the module.
+                xpmoduletype: XP module type.
+                progress_callback: Callback for progress updates.
+                finish_callback: Callback when finished.
+                error_callback: Callback for errors.
+            """
+            finish_callback(mock_action_table)
+
+        mock_service.start.side_effect = mock_start
 
         # Create mock container
         mock_container = Mock(spec=ServiceContainer)
@@ -63,9 +80,7 @@ class TestXp24ActionTableIntegration:
 
         # Verify success
         assert result.exit_code == 0
-        mock_service.download_action_table.assert_called_once_with(
-            self.valid_serial, "xp24"
-        )
+        mock_service.start.assert_called_once()
 
         # Verify JSON output structure
         output = json.loads(result.output)
@@ -77,24 +92,40 @@ class TestXp24ActionTableIntegration:
 
         # Verify action table structure
         action_table = output["action_table"]
-        assert action_table["input1_action"]["type"] == InputActionType.TOGGLE.value
+        assert action_table["input1_action"]["type"] == str(InputActionType.TOGGLE)
         assert action_table["input1_action"]["param"] == TimeParam.NONE.value
-        assert action_table["input2_action"]["type"] == InputActionType.TURNON.value
+        assert action_table["input2_action"]["type"] == str(InputActionType.ON)
         assert action_table["input2_action"]["param"] == TimeParam.T5SEC.value
         assert action_table["mutex34"] is True
         assert action_table["curtain34"] is True
 
     def test_xp24_download_action_table_invalid_serial(self):
-        """Test downloading with invalid serial number"""
-
+        """Test downloading with invalid serial number."""
         # Create mock service with error
         mock_service = Mock(spec=MsActionTableService)
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
-        mock_service.download_action_table.side_effect = MsActionTableError(
-            "Invalid serial number"
-        )
+        # Mock the start method to call error_callback
+        def mock_start(
+            serial_number,
+            xpmoduletype,
+            progress_callback,
+            finish_callback,
+            error_callback,
+        ):
+            """Test helper function.
+
+            Args:
+                serial_number: Serial number of the module.
+                xpmoduletype: XP module type.
+                progress_callback: Callback for progress updates.
+                finish_callback: Callback when finished.
+                error_callback: Callback for errors.
+            """
+            error_callback("Invalid serial number")
+
+        mock_service.start.side_effect = mock_start
 
         # Create mock container
         mock_container = Mock(spec=ServiceContainer)
@@ -111,19 +142,35 @@ class TestXp24ActionTableIntegration:
 
         # Verify error
         assert result.exit_code != 0
-        assert "Invalid serial number" in result.output
+        assert "Error: Invalid serial number" in result.output
 
     def test_xp24_download_action_table_connection_error(self):
-        """Test downloading with network failure"""
-
+        """Test downloading with network failure."""
         # Create mock service with error
         mock_service = Mock(spec=MsActionTableService)
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
-        mock_service.download_action_table.side_effect = MsActionTableError(
-            "Conbus communication failed"
-        )
+        # Mock the start method to call error_callback
+        def mock_start(
+            serial_number,
+            xpmoduletype,
+            progress_callback,
+            finish_callback,
+            error_callback,
+        ):
+            """Test helper function.
+
+            Args:
+                serial_number: Serial number of the module.
+                xpmoduletype: XP module type.
+                progress_callback: Callback for progress updates.
+                finish_callback: Callback when finished.
+                error_callback: Callback for errors.
+            """
+            error_callback("Conbus communication failed")
+
+        mock_service.start.side_effect = mock_start
 
         # Create mock container
         mock_container = Mock(spec=ServiceContainer)
@@ -140,4 +187,4 @@ class TestXp24ActionTableIntegration:
 
         # Verify error
         assert result.exit_code != 0
-        assert "Conbus communication failed" in result.output
+        assert "Error: Conbus communication failed" in result.output
