@@ -26,14 +26,40 @@ class TestConbusDiscoverResponse:
             success=True,
             sent_telegram="<DISCOVER>",
             received_telegrams=["<REPLY1>", "<REPLY2>"],
-            discovered_devices=["device1", "device2"],
+            discovered_devices=[
+                {
+                    "serial_number": "device1",
+                    "module_type": "XP",
+                    "module_type_code": 7,
+                    "module_type_name": "XP24",
+                },
+                {
+                    "serial_number": "device2",
+                    "module_type": "XP",
+                    "module_type_code": 10,
+                    "module_type_name": "XP24P",
+                },
+            ],
             error=None,
             timestamp=timestamp,
         ).to_dict()
         assert result["success"] is True
         assert result["sent_telegram"] == "<DISCOVER>"
         assert result["received_telegrams"] == ["<REPLY1>", "<REPLY2>"]
-        assert result["discovered_devices"] == ["device1", "device2"]
+        assert result["discovered_devices"] == [
+            {
+                "serial_number": "device1",
+                "module_type": "XP",
+                "module_type_code": 7,
+                "module_type_name": "XP24",
+            },
+            {
+                "serial_number": "device2",
+                "module_type": "XP",
+                "module_type_code": 10,
+                "module_type_name": "XP24P",
+            },
+        ]
         assert result["error"] is None
         assert "2025-01-01T12:00:00" in result["timestamp"]
 
