@@ -3,11 +3,11 @@
 import unittest
 from datetime import datetime
 
-from xp.services.telegram_version_service import VersionService
-from xp.models.system_telegram import SystemTelegram
-from xp.models.datapoint_type import DataPointType
-from xp.models.system_function import SystemFunction
-from xp.models.reply_telegram import ReplyTelegram
+from xp.models.telegram.datapoint_type import DataPointType
+from xp.models.telegram.reply_telegram import ReplyTelegram
+from xp.models.telegram.system_function import SystemFunction
+from xp.models.telegram.system_telegram import SystemTelegram
+from xp.services.telegram.telegram_version_service import VersionService
 
 
 class TestVersionService(unittest.TestCase):
