@@ -1,11 +1,16 @@
 """Unit tests for XP24ActionService."""
 
-import pytest
 from unittest.mock import patch
 
-from xp.services.telegram_output_service import TelegramOutputService, XPOutputError
-from xp.models.output_telegram import OutputTelegram
-from xp.models.action_type import ActionType
+import pytest
+
+from xp.models.telegram.action_type import ActionType
+from xp.models.telegram.output_telegram import OutputTelegram
+from xp.services.telegram.telegram_output_service import (
+    TelegramOutputService,
+    XPOutputError,
+)
+from xp.services.telegram.telegram_service import TelegramService
 
 
 class TestXP24ActionService:
@@ -13,7 +18,7 @@ class TestXP24ActionService:
 
     def setup_method(self):
         """Set up test fixtures."""
-        self.service = TelegramOutputService()
+        self.service = TelegramOutputService(telegram_service=TelegramService())
 
     def test_validate_output_number_valid(self):
         """Test validate_output_number with valid inputs."""
@@ -59,7 +64,7 @@ class TestXP24ActionService:
 
     # Telegram generation tests
 
-    @patch("xp.services.telegram_output_service.calculate_checksum")
+    @patch("xp.services.telegram.telegram_output_service.calculate_checksum")
     def test_generate_action_telegram_press(self, mock_checksum):
         """Test generate_action_telegram for PRESS action."""
         mock_checksum.return_value = "FN"
@@ -71,7 +76,7 @@ class TestXP24ActionService:
         assert result == "<S0012345008F27D00AAFN>"
         mock_checksum.assert_called_once_with("S0012345008F27D00AA")
 
-    @patch("xp.services.telegram_output_service.calculate_checksum")
+    @patch("xp.services.telegram.telegram_output_service.calculate_checksum")
     def test_generate_action_telegram_release(self, mock_checksum):
         """Test generate_action_telegram for RELEASE action."""
         mock_checksum.return_value = "FB"
@@ -134,21 +139,20 @@ class TestXP24ActionService:
         """Test parse_status_response with valid response."""
         result = self.service.parse_status_response("<R0012345008F02D12xxxx1110FJ>")
 
-        expected = {0: False, 1: True, 2: True, 3: True}
+        expected = [False, True, True, True]
         assert result == expected
 
     def test_parse_status_response_all_on(self):
         """Test parse_status_response with all inputs ON."""
         result = self.service.parse_status_response("<R0012345008F02D12xxxx1111FJ>")
 
-        expected = {0: True, 1: True, 2: True, 3: True}
+        expected = [True, True, True, True]
         assert result == expected
 
     def test_parse_status_response_all_off(self):
         """Test parse_status_response with all inputs OFF."""
         result = self.service.parse_status_response("<R0012345008F02D12xxxx0000FJ>")
-
-        expected = {0: False, 1: False, 2: False, 3: False}
+        expected = [False, False, False, False]
         assert result == expected
 
     def test_parse_status_response_empty(self):
@@ -158,12 +162,12 @@ class TestXP24ActionService:
 
     def test_parse_status_response_invalid_format(self):
         """Test parse_status_response with invalid format."""
-        with pytest.raises(XPOutputError, match="Invalid status response format"):
+        with pytest.raises(XPOutputError, match="Not a DataPoint telegram"):
             self.service.parse_status_response("<R0012345008F18DFA>")  # ACK telegram
 
     def test_parse_status_response_invalid_bits_length(self):
         """Test parse_status_response with invalid status bits length."""
-        with pytest.raises(XPOutputError, match="Invalid status response format"):
+        with pytest.raises(XPOutputError, match="Not a module_output_state telegram"):
             self.service.parse_status_response(
                 "<R0012345008F02D12xxxx111FJ>"
             )  # Only 3 bits
