@@ -1,4 +1,4 @@
-"""Tests for time parsing utilities"""
+"""Tests for time parsing utilities."""
 
 from datetime import datetime
 
@@ -15,10 +15,10 @@ from xp.utils.time_utils import (
 
 
 class TestTimeUtils:
-    """Test cases for time parsing utilities"""
+    """Test cases for time parsing utilities."""
 
     def test_parse_log_timestamp_valid(self):
-        """Test parsing valid timestamp"""
+        """Test parsing valid timestamp."""
         result = parse_log_timestamp("22:44:20,352")
 
         # Should use today's date by default
@@ -30,7 +30,7 @@ class TestTimeUtils:
         assert result == expected
 
     def test_parse_log_timestamp_with_base_date(self):
-        """Test parsing timestamp with specific base date"""
+        """Test parsing timestamp with specific base date."""
         base_date = datetime(2023, 1, 15, 10, 30, 0)
         result = parse_log_timestamp("22:44:20,352", base_date)
 
@@ -38,7 +38,7 @@ class TestTimeUtils:
         assert result == expected
 
     def test_parse_log_timestamp_edge_cases(self):
-        """Test parsing edge case timestamps"""
+        """Test parsing edge case timestamps."""
         # Midnight
         result = parse_log_timestamp("00:00:00,000")
         assert result.hour == 0
@@ -54,7 +54,7 @@ class TestTimeUtils:
         assert result.microsecond == 999000
 
     def test_parse_log_timestamp_invalid_format(self):
-        """Test parsing invalid timestamp formats"""
+        """Test parsing invalid timestamp formats."""
         invalid_formats = [
             "22:44:20",  # Missing milliseconds
             "22:44:20.352",  # Wrong separator
@@ -73,14 +73,14 @@ class TestTimeUtils:
                 parse_log_timestamp(invalid_timestamp)
 
     def test_format_log_timestamp(self):
-        """Test formatting datetime to log timestamp"""
+        """Test formatting datetime to log timestamp."""
         dt = datetime(2023, 1, 1, 22, 44, 20, 352000)
         result = format_log_timestamp(dt)
 
         assert result == "22:44:20,352"
 
     def test_format_log_timestamp_edge_cases(self):
-        """Test formatting edge case datetimes"""
+        """Test formatting edge case datetimes."""
         # Midnight
         dt = datetime(2023, 1, 1, 0, 0, 0, 0)
         assert format_log_timestamp(dt) == "00:00:00,000"
@@ -94,7 +94,7 @@ class TestTimeUtils:
         assert format_log_timestamp(dt) == "12:30:45,123"
 
     def test_parse_time_range_valid(self):
-        """Test parsing valid time range"""
+        """Test parsing valid time range."""
         start_time, end_time = parse_time_range("22:44:20,352-22:44:25,500")
 
         today = datetime.now().date()
@@ -109,7 +109,7 @@ class TestTimeUtils:
         assert end_time == expected_end
 
     def test_parse_time_range_with_base_date(self):
-        """Test parsing time range with base date"""
+        """Test parsing time range with base date."""
         base_date = datetime(2023, 1, 15)
         start_time, end_time = parse_time_range("10:00:00,000-11:30:15,500", base_date)
 
@@ -120,7 +120,7 @@ class TestTimeUtils:
         assert end_time == expected_end
 
     def test_parse_time_range_invalid_format(self):
-        """Test parsing invalid time range formats"""
+        """Test parsing invalid time range formats."""
         invalid_ranges = [
             "22:44:20,352",  # Missing end time
             "22:44:20,352-",  # Missing end time
@@ -136,12 +136,12 @@ class TestTimeUtils:
                 parse_time_range(invalid_range)
 
     def test_parse_time_range_start_after_end(self):
-        """Test parsing time range where start is after end"""
+        """Test parsing time range where start is after end."""
         with pytest.raises(TimeParsingError, match="Start time .* is after end time"):
             parse_time_range("22:44:25,500-22:44:20,352")
 
     def test_calculate_duration_ms(self):
-        """Test calculating duration in milliseconds"""
+        """Test calculating duration in milliseconds."""
         start = datetime(2023, 1, 1, 22, 44, 20, 352000)
         end = datetime(2023, 1, 1, 22, 44, 25, 500000)
 
@@ -151,7 +151,7 @@ class TestTimeUtils:
         assert duration == expected
 
     def test_calculate_duration_ms_edge_cases(self):
-        """Test duration calculation edge cases"""
+        """Test duration calculation edge cases."""
         # Same time
         dt = datetime(2023, 1, 1, 12, 0, 0, 0)
         assert calculate_duration_ms(dt, dt) == 0
@@ -168,7 +168,7 @@ class TestTimeUtils:
         assert calculate_duration_ms(start, end) == expected
 
     def test_is_valid_log_timestamp(self):
-        """Test timestamp validation function"""
+        """Test timestamp validation function."""
         # Valid timestamps
         valid_timestamps = [
             "00:00:00,000",
@@ -195,7 +195,7 @@ class TestTimeUtils:
             assert is_valid_log_timestamp(timestamp) is False
 
     def test_round_trip_timestamp_conversion(self):
-        """Test that parse -> format -> parse gives same result"""
+        """Test that parse -> format -> parse gives same result."""
         original_timestamps = [
             "00:00:00,000",
             "12:30:45,123",
